@@ -13,12 +13,10 @@ def init_gl(width, height):
     glDepthRange(0, 1)
     glMatrixMode(GL_MODELVIEW)
     glLoadIdentity()
-    glShadeModel(GL_SMOOTH)
     glClearColor(0.0, 0.0, 0.0, 0.0)
     glClearDepth(1.0)
     glDisable(GL_DEPTH_TEST)
     glDisable(GL_LIGHTING)
-    glDepthFunc(GL_LEQUAL)
     glEnable(GL_BLEND)
     glEnable(GL_TEXTURE_2D)
     glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA)
\ No newline at end of file
